==> valentina_0.7.52~dfsg.orig.tar.xz: valentina-v0.7.52/src/libs/ifc/exception/vexceptioninvalidnotch.cpp <==
/************************************************************************
 **
 **  @file   vexceptioninvalidnotch.cpp
 **  @author Roman Telezhynskyi <dismine(at)gmail.com>
 **  @date   28 9, 2018
 **
 **  @brief
 **  @copyright
 **  This source code is part of the Valentina project, a pattern making
 **  program, whose allow create and modeling patterns of clothing.
 **  Copyright (C) 2018 Valentina project
 **  <https://gitlab.com/smart-pattern/valentina> All Rights Reserved.
 **
 **  Valentina is free software: you can redistribute it and/or modify
 **  it under the terms of the GNU General Public License as published by
 **  the Free Software Foundation, either version 3 of the License, or
 **  (at your option) any later version.
 **
 **  Valentina is distributed in the hope that it will be useful,
 **  but WITHOUT ANY WARRANTY; without even the implied warranty of
 **  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 **  GNU General Public License for more details.
 **
 **  You should have received a copy of the GNU General Public License
 **  along with Valentina.  If not, see <http://www.gnu.org/licenses/>.
 **
 *************************************************************************/
#include "vexceptioninvalidnotch.h"

//---------------------------------------------------------------------------------------------------------------------
VExceptionInvalidNotch::VExceptionInvalidNotch(const QString &error) V_NOEXCEPT_EXPR (true)
    :VException(error)
{}

//---------------------------------------------------------------------------------------------------------------------
VExceptionInvalidNotch::VExceptionInvalidNotch(const VExceptionInvalidNotch &e) V_NOEXCEPT_EXPR (true)
    :VException(e)
{}

//---------------------------------------------------------------------------------------------------------------------
VExceptionInvalidNotch &VExceptionInvalidNotch::operator=(const VExceptionInvalidNotch &e) V_NOEXCEPT_EXPR (true)
{
    if ( &e == this )
    {
        return *this;
    }
    VException::operator=(e);
    return *this;
}

==> valentina_1.0.0~dfsg.orig.tar.xz: valentina-v1.0.0/src/libs/ifc/exception/vexceptioninvalidnotch.cpp <==
/************************************************************************
 **
 **  @file   vexceptioninvalidnotch.cpp
 **  @author Roman Telezhynskyi <dismine(at)gmail.com>
 **  @date   28 9, 2018
 **
 **  @brief
 **  @copyright
 **  This source code is part of the Valentina project, a pattern making
 **  program, whose allow create and modeling patterns of clothing.
 **  Copyright (C) 2018 Valentina project
 **  <https://gitlab.com/smart-pattern/valentina> All Rights Reserved.
 **
 **  Valentina is free software: you can redistribute it and/or modify
 **  it under the terms of the GNU General Public License as published by
 **  the Free Software Foundation, either version 3 of the License, or
 **  (at your option) any later version.
 **
 **  Valentina is distributed in the hope that it will be useful,
 **  but WITHOUT ANY WARRANTY; without even the implied warranty of
 **  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 **  GNU General Public License for more details.
 **
 **  You should have received a copy of the GNU General Public License
 **  along with Valentina.  If not, see <http://www.gnu.org/licenses/>.
 **
 *************************************************************************/
#include "vexceptioninvalidnotch.h"

//---------------------------------------------------------------------------------------------------------------------
VExceptionInvalidNotch::VExceptionInvalidNotch(const QString &error) V_NOEXCEPT_EXPR (true)
    :VException(error)
{}

//---------------------------------------------------------------------------------------------------------------------
VExceptionInvalidNotch::VExceptionInvalidNotch(const VExceptionInvalidNotch &e) V_NOEXCEPT_EXPR (true)
    :VException(e)
{}

//---------------------------------------------------------------------------------------------------------------------
auto VExceptionInvalidNotch::operator=(const VExceptionInvalidNotch &e) V_NOEXCEPT_EXPR(true)
    -> VExceptionInvalidNotch &
{
    if ( &e == this )
    {
        return *this;
    }
    VException::operator=(e);
    return *this;
}
